## What's Changed

### fixes

- feat(chat): refactor message rendering and introduce ToolCallItem component
- fix(db): using lambda expression to ensure updated_at field ([#4730](https://github.com/AstrBotDevs/AstrBot/issues/4730))
- fix(skills): update SANDBOX_SKILLS_ROOT path to use relative directory
